Package: neuroimaGene
Type: Package
Title: Transcriptomic Atlas of Neuroimaging Derived Phenotypes
Version: 0.1.4
Authors@R: c(person("Xavier", "Bledsoe", 
                    email = "xbledsoe22@gmail.com", 
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-6091-9372")),
            person("Eric", "Gamazon", 
                    email = "egamazon@vumc.org", 
                    role = c("aut"),
                    comment = c(ORCID = "0000-0003-4204-8734")))
Maintainer: Xavier Bledsoe <xbledsoe22@gmail.com>
Description: Contains functions to query and visualize the Neuroimaging features 
  associated with genetically regulated gene expression (GReX). The primary utility,
  neuroimaGene(), relies on a list of user-defined genes and returns a table of
  neuroimaging features (NIDPs) associated with each gene. This resource 
  is designed to assist in the interpretation of genome-wide and transcriptome-wide
  association studies that evaluate brain related traits. Bledsoe (2024) 
  <doi:10.1016/j.ajhg.2024.06.002>. In addition there are several visualization 
  functions that generate summary plots and 2-dimensional visualizations of regional 
  brain measures. Mowinckel (2020).
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Imports: data.table, ggplot2, DBI, stringr, ggseg, sf, RSQLite
Depends: R (>= 3.5.0)
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-29 04:12:40 UTC; xbledsoe
Author: Xavier Bledsoe [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6091-9372>),
  Eric Gamazon [aut] (ORCID: <https://orcid.org/0000-0003-4204-8734>)
Repository: CRAN
Date/Publication: 2026-04-29 15:10:09 UTC
Built: R 4.5.2; ; 2026-04-29 15:39:32 UTC; unix
